exceptiontools.MusicContentsError
=================================

.. abjad-lineage:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError

.. autoclass:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__unicode__
   :noindex:
